LangTextConverter class abstract
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
String data) → StringBuffer -
createLangText(
String flag, {required int index}) → LangText? -
isIterableStart(
String value, Iterable< String> startFlags) → bool -
isStart(
String value, String startFlag) → bool - start with LangText
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited